@@ -273,8 +273,8 @@ class DynamicValidator:
             - report: ValidationReport; report where results are added
 
         Returns:
-            - False if recent_df is empty, else (recent_df, reference_api_df)
-            (after reference_api_df has been padded if necessary)
+            - False if recent_df is empty after padding, else (recent_df, reference_api_df)
+            (reference_api_df will be padded if necessary)
         """
         # recent_lookbehind: start from the check date and working backward in time,
         # how many days at a time do we want to check for anomalies?
@@ -320,47 +320,71 @@ class DynamicValidator:
         reference_api_df = api_df_or_error.query(
             "time_value >= @reference_start_date & time_value <= @reference_end_date")
 
-        report.increment_total_checks()
+        pre_pad_empty_flag = reference_api_df.empty
+        reference_api_df = self.pad_reference_api_df(
+            reference_api_df, geo_sig_df, reference_start_date, reference_end_date)
 
+        report.increment_total_checks()
         if reference_api_df.empty:
-            report.add_raised_error(
-                ValidationFailure("empty_reference_data",
+            report.add_raised_error(ValidationFailure("empty_reference_data",
                                   checking_date,
                                   geo_type,
                                   signal_type,
                                   "reference data is empty; comparative checks could not "
                                   "be performed"))
             return False
-
-        reference_api_df = self.pad_reference_api_df(
-            reference_api_df, geo_sig_df, reference_end_date)
+        if pre_pad_empty_flag:
+            report.add_raised_warning(ValidationFailure("empty_reference_data",
+                                  checking_date,
+                                  geo_type,
+                                  signal_type,
+                                  "pre-padding reference data is empty and indicates data "
+                                  "missing from the API; please verify that this is expected"))
 
         return (geo_sig_df, reference_api_df)
 
-    def pad_reference_api_df(self, reference_api_df, geo_sig_df, reference_end_date):
+    # `reference_start_date` is used in the call to `geo_sig_df.query()`
+    # below but pylint doesn't recognize that.
+    # pylint: disable=unused-argument
+    def pad_reference_api_df(self, reference_api_df, geo_sig_df,
+                             reference_start_date, reference_end_date):
         """Check if API data is missing, and supplement from test data.
 
         Arguments:
             - reference_api_df: API data within lookbehind range
             - geo_sig_df: Test data
-            - reference_end_date: Supposed end date of reference data
+            - reference_start_date: Desired start date of reference data
+            - reference_end_date: Desired end date of reference data
 
         Returns:
             - reference_api_df: Supplemented version of original
         """
+        # Value is `NaT` (not a time) if reference_api_df is empty.
         reference_api_df_max_date = reference_api_df.time_value.max().date()
-        if reference_api_df_max_date < reference_end_date:
-            # Querying geo_sig_df, only taking relevant rows
+        if reference_api_df.empty:
+            geo_sig_df_supplement = geo_sig_df.query(
+                'time_value <= @reference_end_date & time_value >= \
+                @reference_start_date')[[
+                "geo_id", "val", "se", "sample_size", "time_value"]]
+        elif reference_api_df_max_date < reference_end_date:
+            # If actual end date `reference_api_df_max_date` is not as recent as
+            # the desired end date `reference_end_date`, add rows from recently
+            # generate data, in `geo_sig_df`, to the reference data.
             geo_sig_df_supplement = geo_sig_df.query(
                 'time_value <= @reference_end_date & time_value > \
                 @reference_api_df_max_date')[[
                 "geo_id", "val", "se", "sample_size", "time_value"]]
-            # Matching time_value format
-            geo_sig_df_supplement["time_value"] = \
-                pd.to_datetime(geo_sig_df_supplement["time_value"],
-                    format = "%Y-%m-%d %H:%M:%S")
-            reference_api_df = pd.concat(
-                [reference_api_df, geo_sig_df_supplement])
+        else:
+            return reference_api_df
+
+        # Final processing after supplementing reference_api_df
+        # Matching time_value format
+        geo_sig_df_supplement["time_value"] = \
+            pd.to_datetime(geo_sig_df_supplement["time_value"],
+                format = "%Y-%m-%d %H:%M:%S")
+        reference_api_df = pd.concat(
+            [reference_api_df, geo_sig_df_supplement])
+
         return reference_api_df
 
     def check_max_date_vs_reference(self, df_to_test, df_to_reference, checking_date,
